@@ -1,6 +1,7 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek-config.h"
+#include "zeek/analyzer/protocol/dce-rpc/DCE_RPC.h"
 
 #include <stdlib.h>
 #include <string>
@@ -8,13 +9,10 @@
 
 using namespace std;
 
-#include "DCE_RPC.h"
+namespace zeek::analyzer::dce_rpc {
 
-using namespace analyzer::dce_rpc;
-
-
-DCE_RPC_Analyzer::DCE_RPC_Analyzer(Connection *conn)
-: tcp::TCP_ApplicationAnalyzer("DCE_RPC", conn)
+DCE_RPC_Analyzer::DCE_RPC_Analyzer(Connection* conn)
+	: analyzer::tcp::TCP_ApplicationAnalyzer("DCE_RPC", conn)
 	{
 	had_gap = false;
 	interp = new binpac::DCE_RPC::DCE_RPC_Conn(this);
@@ -39,7 +37,7 @@ void DCE_RPC_Analyzer::EndpointEOF(bool is_orig)
 	interp->FlowEOF(is_orig);
 	}
 
-void DCE_RPC_Analyzer::Undelivered(uint64 seq, int len, bool orig)
+void DCE_RPC_Analyzer::Undelivered(uint64_t seq, int len, bool orig)
 	{
 	TCP_ApplicationAnalyzer::Undelivered(seq, len, orig);
 	had_gap = true;
@@ -63,6 +61,8 @@ void DCE_RPC_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 		}
 	catch ( const binpac::Exception& e )
 		{
-		ProtocolViolation(fmt("Binpac exception: %s", e.c_msg()));
+		ProtocolViolation(util::fmt("Binpac exception: %s", e.c_msg()));
 		}
 	}
+
+} // namespace zeek::analyzer::dce_rpc
